/*Calculate the proportion of access denied, hazardous and census water and
  re-calculated the number of plots per stratum*/
/*
%let cond_status_cd = 1;
*/

%macro access_denied;

%if &use_idb. = 1 %then %do;
  %let ppsa_cond_connection = ppsa.plot_id = c.plot_id;
  %let ppsa_eus_connection = ppsa.evalid = eus.evalid and ppsa.stratumcd = eus.stratumcd;
  %let cond_attribute_connection = t.cond_id = c.cond_id;
  %let condprop=cond_wt;
  %let macrprop=cond_wt;
  %let micrprop=cond_wt;
  %let subpprop=cond_wt;
/*  %let not_access_denied=glc in (20,30,40,41,42,43,44,45,46,47,48,49,50,60,61,62,63,64,65,66,67,68,69,92) and stand_size_class ne 7;
*/
  %let not_access_denied=cond_wt > 0;
/*  %let not_access_denied=1;*/
  %let plot_var=plot_id;
%end;
%else %do;
  %let condprop=condprop_unadj;
  %let macrprop=macrprop_unadj;
  %let micrprop=micrprop_unadj;
  %let subpprop=subpprop_unadj;

  %let tpa=tpa_unadj;

  %if &census_water. = 1 %then
    %let not_access_denied=c.cond_status_cd in (1,2,3,4);
  %else
    %let not_access_denied=c.cond_status_cd in (1,2,3);
  %let plot_var=plot;
%end;


%if  "&datasource_nims_40." ne "" %then %do;
  %let use_ppsa = &ppsa.;
  data eus_temp;
    set &eus.;
  run;

  %let ppsa_cond_connection = ppsa.plt_cn = c.plt_cn;
  %let dwm_cond_connection = dwm.plt_cn = c.plt_cn and dwm.condid = c.condid;
  %let ppsa_eus_connection = ppsa.rscd = eus.rscd and ppsa.evalid = eus.evalid and 
                             ppsa.stratumcd = eus.stratumcd and ppsa.estunit = eus.estunit;
  %let cond_attribute_connection = t.condid = c.condid and t.plt_cn = c.plt_cn;

  %let ppsa_sort_by_var = ppsa.evalid, ppsa.estunit, ppsa.statecd, ppsa.stratumcd, ppsa.plot, ppsa.countycd, ppsa.invyr, ppsa.inv_vst_nbr;


/*
  %let ppsa_cond_connection = ppsa.plot = c.plot and ppsa.statecd = c.statecd 
                              and ppsa.countycd = c.countycd and ppsa.subcycle = c.subcycle
                              and ppsa.cycle = c.cycle and ppsa.unitcd = c.unitcd;

  %let dwm_cond_connection = dwm.plot = c.plot and dwm.statecd = c.statecd and
                             dwm.cycle = c.cycle and dwm.subcycle = c.subcycle and
                             dwm.countycd = c.countycd and dwm.condid = c.condid;

  %let ppsa_eus_connection = ppsa.rscd = eus.rscd and ppsa.evalid = eus.evalid and 
                             ppsa.stratumcd = eus.stratumcd and ppsa.estunit = eus.estunit;

  %let cond_attribute_connection = t.condid = c.condid and t.plot = c.plot and 
                              t.statecd = c.statecd and t.countycd = c.countycd and 
                              t.subcycle=c.subcycle and t.cycle=c.cycle;
*/

%end;
%else %if  "&datasource_fiadb_40." ne "" %then %do;
  data pop_plot_stratum_assgn;
    set &pop_plot_stratum_assgn;
	estunit = estn_unit;
	cycle = 1;
	subcycle = 1;
  run;

  %let use_ppsa = pop_plot_stratum_assgn;
  %let ppsa_cond_connection = ppsa.plt_cn = c.plt_cn;
  %let dwm_cond_connection = dwm.plt_cn = c.plt_cn and dwm.condid = c.condid;
  %let ppsa_eus_connection = ppsa.stratum_cn = eus.stratum_cn;
  %let cond_attribute_connection = t.condid = c.condid and t.plt_cn = c.plt_cn;

  %let ppsa_sort_by_var = ppsa.evalid, ppsa.estunit, ppsa.statecd, ppsa.stratumcd, ppsa.plot, ppsa.countycd, ppsa.invyr, ppsa.inv_vst_nbr;


  data pop_stratum;
    set &pop_stratum.;
	stratum_cn = cn;
  run;

  proc sort data = pop_stratum;
    by rscd evalid estn_unit stratumcd;
  run;

  data pop_eval;
    set &pop_eval.;
  run;

  proc sort data = pop_eval;
    by rscd evalid;
  run;

  data pop_estn_unit;
    set &pop_estn_unit.;
    estunit = estn_unit;
  run;

  proc sort data = pop_estn_unit;
    by rscd evalid estn_unit ;
  run;



  data eus_temp;
    merge pop_stratum 
          pop_eval(keep = rscd evalid eval_descr);
    by rscd evalid;
    estunit = estn_unit;
    evaldescr = eval_descr;
  run;

  data eus_temp;
    merge eus_temp pop_estn_unit;
    by rscd evalid estn_unit;
    p1pointcnt_eu = p1pntcnt_eu;
  run;

%end;

proc sql;
  create table ppsa_temp as
   select * from 
	  (select * from
         (select distinct ppsa.evalid, ppsa.estunit, ppsa.statecd, ppsa.stratumcd, ppsa.plot, 
               ppsa.countycd, ppsa.subcycle, ppsa.cycle, ppsa.unitcd, 
               sum(case when &not_access_denied then 0 else c.&macrprop. end) as denied_macr,
               sum(case when &not_access_denied then 0 else c.&micrprop. end) as denied_micr,
               sum(case when &not_access_denied then 0 else c.&subpprop. end) as denied_subp,
               sum(case when &not_access_denied then 0 else c.&condprop. end) as denied_cond
	           from &use_ppsa. ppsa,
				    &cond. c,
					eus_temp eus
	             where &ppsa_cond_connection. and &ppsa_eus_connection.
		                group by ppsa.evalid, ppsa.estunit, ppsa.statecd, ppsa.stratumcd, 
                              ppsa.plot, ppsa.countycd, ppsa.subcycle, ppsa.cycle, ppsa.unitcd
		  ) as a
		where denied_cond ne 1
        group by a.evalid, ppsa.statecd, ppsa.estunit, a.stratumcd, a.plot, a.countycd,
                 a.subcycle, a.cycle, a.unitcd
       ) as denied,
	     &use_ppsa. ppsa
		 where ppsa.evalid    = denied.evalid and
		       ppsa.estunit   = denied.estunit and
		       ppsa.stratumcd = denied.stratumcd and
			   ppsa.plot      = denied.plot and
			   ppsa.statecd   = denied.statecd and
			   ppsa.countycd  = denied.countycd and
			   ppsa.subcycle  = denied.subcycle and
			   ppsa.cycle     = denied.cycle and
		       ppsa.unitcd    = denied.unitcd
;
quit;


/*
%if %sysfunc(exist(eus_access)) = 0 or &update_all_files.=1 %then %do;
*/
proc sql;
  create table eus_access as
    select distinct
           eus.rscd, eus.evalid, eus.estunit, eus.stratumcd, eus.arealand_eu, eus.areatot_eu,
           eus.area_used, count.p2pointcnt_man as p2pointcnt_man,
           eus.p1pointcnt, eus.p1pointcnt_eu, eus.p2pointcnt,
%if &use_idb. = 1 %then %do;
               eus.AdjFactor_R5 as pmh_macr,
               eus.AdjFactor_R5 as pmh_micr,
               eus.AdjFactor_R5 as pmh_subp,
               eus.AdjFactor_R5 as pmh_cond
%end;
%else %do;

           sum(c.&macrprop.*(case when &not_access_denied. then 1 else 0 end))/sum(c.&macrprop.) as pmh_macr,
           sum(c.&micrprop.*(case when &not_access_denied. then 1 else 0 end))/sum(c.&micrprop.) as pmh_micr,
           sum(c.&subpprop.*(case when &not_access_denied. then 1 else 0 end))/sum(c.&subpprop.) as pmh_sub,
           sum(c.&condprop.*(case when &not_access_denied. then 1 else 0 end))/sum(c.&condprop.) as pmh_cond
           %if "&dwm_cond_source." ne "" %then %do;
		      ,
			  sum(dwm.cwdprop*(case when &not_access_denied. then 1 else 0 end))/sum(dwm.cwdprop) as pmh_cwd,
			  sum(dwm.fwd_small_prop*(case when &not_access_denied. then 1 else 0 end))/sum(dwm.fwd_small_prop) as pmh_fwd_small,
			  sum(dwm.fwd_medium_prop*(case when &not_access_denied. then 1 else 0 end))/sum(dwm.fwd_medium_prop) as pmh_fwd_medium,
			  sum(dwm.fwd_large_prop*(case when &not_access_denied. then 1 else 0 end))/sum(dwm.fwd_large_prop) as pmh_fwd_large
		   %end;
%end;
		from &cond. c, 
		     ppsa_temp ppsa,
			 eus_temp  eus,
             (select eus.rscd, eus.evalid, eus.estunit, eus.stratumcd, 
                     count(ppsa.&plot_var.) as p2pointcnt_man
				 from ppsa_temp ppsa,
			          eus_temp  eus
		           where &ppsa_eus_connection.
		              group by eus.rscd, eus.evalid, eus.estunit, eus.stratumcd
                ) as count
                %if "&dwm_cond_source." ne "" %then %do;
			           ,
					   (
					   select dwm.statecd, dwm.countycd, dwm.cycle, dwm.subcycle, dwm.plot, dwm.condid, 
                              sum(dwm.cwd_tl)/dwm.cwd_tl_plot_unadj as cwdprop,
                              sum(dwm.fwd_sm_tl)/dwm.fwd_sm_tl_plot_unadj as fwd_small_prop,
                              sum(dwm.fwd_md_tl)/dwm.fwd_md_tl_plot_unadj as fwd_medium_prop,
                              sum(dwm.fwd_lg_tl)/dwm.fwd_lg_tl_plot_unadj as fwd_large_prop
					     from &dwm. as dwm/*,
						   (
					        select statecd, countycd, plot, cycle, subcycle,
                                   sum(cwd_tl)    as cwd_tl_plot_all, 
                                   sum(fwd_sm_tl) as fwd_small_tl_all,
                                   sum(fwd_md_tl) as fwd_medium_tl_all,
                                   sum(fwd_lg_tl) as fwd_large_tl_all
					           from &dwm. dwm
						         group by statecd, countycd, cycle, subcycle, plot
						   ) as dwm_sum 
*/
/*
						   where dwm_sum.statecd = dwm.statecd and dwm_sum.plot = dwm.plot and
						         dwm_sum.countycd = dwm.countycd and dwm_sum.cycle = dwm.cycle and
								 dwm_sum.subcycle = dwm.subcycle
*/
						     group by dwm.statecd, dwm.countycd, dwm.cycle, dwm.subcycle, dwm.plot, dwm.condid
					   ) as dwm
                %end;
		where &ppsa_cond_connection. and 
		      &ppsa_eus_connection. and
			  eus.rscd      = count.rscd and
			  eus.evalid    = count.evalid and
			  eus.estunit   = count.estunit and
		      eus.stratumcd = count.stratumcd 
              %if "&dwm_cond_source." ne "" %then %do;
                 and &dwm_cond_connection.
  		      %end;


		group by eus.rscd, eus.evalid, eus.estunit, eus.stratumcd, eus.arealand_eu, eus.areatot_eu, 
                  eus.area_used, eus.p1pointcnt, eus.p1pointcnt_eu, eus.p2pointcnt
	     ;
quit;

data ppsa_temp;
  set ppsa_temp;
run;

data eus_access;
  set eus_access;
  if p1pointcnt = p1pointcnt_eu or p1pointcnt = . or p1pointcnt_eu =. then double_sampling = 0;
  else double_sampling = 1;
  if p1pointcnt_eu > 0 then do;
     stratum_area = area_used*p1pointcnt/p1pointcnt_eu;
  end;
*  if &use_idb. = 1 then p2pointcnt_man = p2pointcnt;
/*  pmh_cwd=1;*/
run;

proc sort data = eus_access;
  by rscd evalid estunit stratumcd;
run;

proc sort data = eus_temp;
  by rscd evalid estunit stratumcd;
run;

data eus_access;
  merge eus_access eus_temp(drop = p1pointcnt p1pointcnt_eu /*tablenm rscd stratummethod*/ arealand_eu areatot_eu p2pointcnt area_used);
  by rscd evalid estunit stratumcd;
  if pmh_micr = . then pmh_micr = pp_samp_ratio_micro;
  if pmh_macr = . then pmh_macr = pp_samp_ratio_macro;
  if pmh_sub = . then pmh_sub =pp_samp_ratio_subp;
  if pmh_cond = . then pmh_cond = pp_samp_ratio_subp;


  if adj_factor_micr > 0 then pmh_micr_db = 1/adj_factor_micr;
  if adj_factor_macr > 0 then pmh_macr_db = 1/adj_factor_macr;
  if adj_factor_subp > 0 then pmh_sub_db  = 1/adj_factor_subp;
  if adj_factor_macr > 0 then pmh_cond_db = 1/adj_factor_macr;
  else if adj_factor_subp > 0 then pmh_cond_db = 1/adj_factor_subp;



/*  
  stratum_area = expns * p2pointcnt;
*/ 
  if evalid in (680,681) then do;
     pmh_micr = pp_samp_ratio_micro;
     pmh_macr = pp_samp_ratio_macro;
     pmh_sub =pp_samp_ratio_subp;
     pmh_cond = pp_samp_ratio_subp;
  end;
run;


/*
%end;
*/
%mend;


*%access_denied;

