

%macro estimation;
%let table_name = estimation;


%if &ratio_y_n. eq 1 %then %do;
  %let ratio_num=2;
%end;
%else %do;
  %let ratio_num=1;
%end;


proc sql;
  create table &table_name. as

/* 1a */
  select   
   %do row_run=1 %to &max_row_num.;
     %do col_run=1 %to &max_col_num.;
	   %if &ratio_y_n. eq 1 %then %do;
  	     (case when (sum(r_c_&row_run._&col_run._y) = 0 ) 
               then .
               else
	             (sum(r_c_&row_run._&col_run._x)/sum(r_c_&row_run._&col_run._y))
			   end)/(&units.)
            as r_c_&row_run._&col_run.,

	     (case when (sum(r_c_&row_run._&col_run._y) = 0 ) 
               then .
               else
	           (
	     sqrt(1/(sum(r_c_&row_run._&col_run._y) **2) *
                (  sum(var_r_c_&row_run._&col_run._x) 
                 + ((sum(r_c_&row_run._&col_run._x)/sum(r_c_&row_run._&col_run._y))**2) * sum(var_r_c_&row_run._&col_run._y)
                 - 2*sum(r_c_&row_run._&col_run._x)/sum(r_c_&row_run._&col_run._y)*sum(covar_r_c_&row_run._&col_run._xy)
                ))
			    )
			   end)/(&units.)
			  as std_r_c_&row_run._&col_run.,
		%end;
		%else %do;
           sum(r_c_&row_run._&col_run._x)/(&units.) as r_c_&row_run._&col_run.,
           sqrt(sum(var_r_c_&row_run._&col_run._x))/(&units.) as std_r_c_&row_run._&col_run.,
		%end;

		%if &count_plots_non_zero.=1 %then %do;
		   sum(sssum_r_c_num_&row_run._&col_run._x) as r_c_num_&row_run._&col_run.,
		%end;

	 %end;
   %end;
   g.evalid_group
  from (
/* 1b */
/* Summarizing at Evalid Level 
*/
  select   
  %do row_run=1 %to &max_row_num.;
    %do col_run=1 %to &max_col_num.;
      %do r=1 %to &ratio_num.;
          %let x_y=%scan(&r_var., &r.);
		  sum(var_r_c_&row_run._&col_run._&x_y.) as var_r_c_&row_run._&col_run._&x_y.,
		  (case when ("&subtract." <> "" & t.evalid in (&subtract.)) 
              then -1 
              else 1 end)*
          sum(r_c_&row_run._&col_run._&x_y.) as r_c_&row_run._&col_run._&x_y.,
  		  %if &count_plots_non_zero.=1 %then %do;
			  sum(ssum_r_c_num_&row_run._&col_run._&x_y.) as sssum_r_c_num_&row_run._&col_run._&x_y.,
		  %end;
       %end;
	   %if &ratio_y_n. eq 1 %then %do;
	     sum(covar_r_c_&row_run._&col_run._xy) as covar_r_c_&row_run._&col_run._xy,
	   %end;
	 %end;
   %end;
   t.evalid

  from (
/* 2 */
/* Summarizing at Estunit Level 
*/
  select   
  %do row_run=1 %to &max_row_num.;
    %do col_run=1 %to &max_col_num.;
      %do r=1 %to &ratio_num.;
          %let x_y=%scan(&r_var., &r.);
           (sum(total_area**2/num_plots *   
                   (
                    stratum_area/total_area* eus.p2pointcnt_man * var_r_c_&row_run._&col_run._&x_y.  + 
                    (1 - stratum_area/total_area) * eus.p2pointcnt_man/num_plots * var_r_c_&row_run._&col_run._&x_y.
                   )
                  )
              ) as var_r_c_&row_run._&col_run._&x_y.,
               
           sum(eus.stratum_area * s.sum_r_c_&row_run._&col_run._&x_y. /(eus.p2pointcnt_man)) as r_c_&row_run._&col_run._&x_y.,
  		   %if &count_plots_non_zero.=1 %then %do;
			  sum(sum_r_c_num_&row_run._&col_run._&x_y.) as ssum_r_c_num_&row_run._&col_run._&x_y.,
		   %end;
       %end;
	   %if &ratio_y_n. eq 1 %then %do;
         (sum(total_area**2/num_plots *   
               (
                stratum_area/total_area* eus.p2pointcnt_man * covar_r_c_&row_run._&col_run._xy  + 
                (1 - stratum_area/total_area) * eus.p2pointcnt_man/num_plots * covar_r_c_&row_run._&col_run._xy
               )
              )
            )  as covar_r_c_&row_run._&col_run._xy,
		%end;
	 %end;
   %end;
   s.evalid, s.estunit/*, s.statecd*/

  from (
  select 
/* 3 */
/* Summarizing at Plot Level
*/

  %do row_run=1 %to &max_row_num.;
     %do col_run=1 %to &max_col_num.;
	    %if &ratio_y_n. eq 1 %then %do;
 	       sum((p.r_c_&row_run._&col_run._x - r_c_mean_&row_run._&col_run._x)*
		       (p.r_c_&row_run._&col_run._y - r_c_mean_&row_run._&col_run._y))/(p2pointcnt_man*(p2pointcnt_man-1)) as
			   covar_r_c_&row_run._&col_run._xy,
		%end;
        %do r=1 %to &ratio_num.;
           %let x_y=%scan(&r_var., &r.);
/*		   mean(r_c_&row_run._&col_run._&x_y.) as r_c_mean_&row_run._&col_run._&x_y.,*/

/*           sum(p.r_c_&row_run._&col_run._&x_y.) as r_c_&row_run._&col_run._&x_y., */
/* This line needed to be changed because of a bug in SAS 9.2 */
           sum(p.r_c_&row_run._&col_run._&x_y.) as sum_r_c_&row_run._&col_run._&x_y., 
           var(p.r_c_&row_run._&col_run._&x_y.)/eus.p2pointcnt_man as var_r_c_&row_run._&col_run._&x_y.,
		   %if &count_plots_non_zero.=1 %then %do;
			  sum(r_c_num_&row_run._&col_run._&x_y.) as sum_r_c_num_&row_run._&col_run._&x_y.,
		   %end;
        %end;
		
     %end;
  %end;
  eus.evalid, eus.estunit, /*p.statecd,*/ eus.stratumcd, eus.p2pointcnt_man
  from (
/* 4a */
/* Calculate mean for x and y variable
*/
    select
	%do r=1 %to &ratio_num.;
	  %let x_y=%scan(&r_var., &r.);

	  %do row_run=1 %to &max_row_num.;
        %do col_run=1 %to &max_col_num.;
          r_c_&row_run._&col_run._&x_y.,
		  mean(r_c_&row_run._&col_run._&x_y.) as r_c_mean_&row_run._&col_run._&x_y.,
		  %if &count_plots_non_zero.=1 %then %do;
		     r_c_num_&row_run._&col_run._&x_y.,
		  %end;
	    %end;
      %end;
	%end;
    p.evalid, p.estunit, p.statecd, p.countycd, p.subcycle, p.cycle, p.stratumcd, p.plot
    from (
/* 4b */
/* Set missing values at plot level to zero
*/
    select
	%do r=1 %to &ratio_num.;
	  %let x_y=%scan(&r_var., &r.);

	  %do row_run=1 %to &max_row_num.;
        %do col_run=1 %to &max_col_num.;
          (case when (c.r_c_&row_run._&col_run._&x_y. is NULL) 
              then 0 
              else c.r_c_&row_run._&col_run._&x_y. end) as r_c_&row_run._&col_run._&x_y.,
		  %if &count_plots_non_zero.=1 %then %do;
		   (case when (c.r_c_&row_run._&col_run._&x_y. > 0) 
              then 1 
              else 0 end) as r_c_num_&row_run._&col_run._&x_y.,
		  %end;
	    %end;
      %end;
	%end;
    ppsa.evalid, ppsa.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle, ppsa.cycle,
    ppsa.stratumcd, ppsa.plot
    from 
     ( select 
     %do r=1 %to &ratio_num.;
	   %let x_y=%scan(&r_var., &r.);
	   %do row_run=1 %to &max_row_num.;
         %do col_run=1 %to &max_col_num.;
            r_c_&row_run._&col_run._&x_y.,
		 %end;
	   %end;
	 %end;
	 %if &ratio_y_n. eq 1 %then %do;
	   max(x_var.evalid, y_var.evalid) as evalid, 
	   max(x_var.estunit, y_var.estunit) as estunit, 
       max(x_var.statecd,y_var.statecd) as statecd, 
       max(x_var.countycd,y_var.countycd) as countycd, 
       max(x_var.subcycle, y_var.subcycle) as subcycle, 
       max(x_var.cycle, y_var.cycle) as cycle, 
       max(x_var.stratumcd,y_var.stratumcd) as stratumcd,
       max(x_var.plot,y_var.plot) as plot
     %end;
	 %else %do;
  	   x_var.evalid, x_var.estunit, x_var.statecd, x_var.countycd, x_var.subcycle, x_var.cycle, 
       x_var.stratumcd, x_var.plot
	 %end;
    from
  %do r=1 %to &ratio_num.;
    %let x_y=%scan(&r_var., &r.);
	  (
    %if "&&variable1&x_y." ne "AREA" and "&attribute_type." ne "MIXED" %then %do;
/* 5A */
/* Summarizing at Tree/Attribute Level 
*/  
     select 
         %do row_run=1 %to &max_row_num.;
           %do col_run=1 %to &max_col_num.;
		     %let col_ = col_rest&col_run.&x_y.;
             sum(case when (&&row_rest&row_run.&x_y.) and 
                           (&&col_rest&col_run.&x_y.) and 
                           (&&restrictions&x_y.)
				   %if &max_variable_of_interest. =1 %then %do;
				     %let var_num = 1;
				   %end;
				   %else %if &&variable_direction&x_y.=2 %then %do;
                     %let var_num =&&row_var&row_run.&x_y.;
				   %end;
				   %else %do;
                     %let var_num =&&col_var&col_run.&x_y.;
				   %end;

                 %if &use_idb. = 1 %then %do;
                   then ( /*c.&condprop.* */ (&&variable&var_num.&x_y.)
				    %if &use_adj_db. = 1 %then %do; 
						/eus.pmh_cond_db)
				    %end;
				    %else %do;
						/eus.pmh_cond)
					%end;
			     %end;
				 %else %if "&attribute_type." = "TREE" %then %do;
                   then (&tpa. * (&&variable&var_num.&x_y.) / 
                     (
					 %if &use_cond_adj. = 1 %then %do; 
						eus.pmh_cond
					 %end;
					 %else %do;
                        case 
					    %if &use_adj_db. = 1 %then %do; 
	                        when &tpa. < 1 then eus.pmh_macr_db
	                        when &tpa. < 7 then eus.pmh_sub_db
	                        else eus.pmh_micr_db 
					    %end;
					    %else %do;
	                        when &tpa. < 1 then eus.pmh_macr
	                        when &tpa. < 7 then eus.pmh_sub
	                        else eus.pmh_micr 
						%end;
                        end
                        %end;
                        ))
				 %end;
				 %else %if "&attribute_type." ne "TREE" %then %do;
                   then ((&&variable&var_num.&x_y.) / &adj_factor.)
				 %end;
				 %else %do; 
				   then 0
				 %end;
                 else 0
		  	     end) as r_c_&row_run._&col_run._&x_y.,
           %end;
         %end;
         eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle, ppsa.cycle, 
         ppsa.stratumcd, ppsa.plot
	     from &cond. c,		      
	 	      ppsa_temp ppsa,
		      eus_access  eus,
		      &&attribute_table&x_y. t
           %if "&&add_table&x_y." ne "" %then %do;
		      , &&add_table&x_y.
		   %end;
      where &cond_attribute_connection. and &ppsa_cond_connection. and &ppsa_eus_connection. and
			eus.evalid in (&evalid.)
           %if "&&add_connection&x_y." ne "" %then %do;
		    and (&&add_connection&x_y.)
           %end;
	  group by eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle, ppsa.cycle, 
               ppsa.stratumcd, ppsa.plot
%end;
%else %if "&&variable1&x_y." eq "AREA" and "&attribute_type." ne "MIXED" %then %do;
/* 5b */
/*Summarizing area*/
     select 
         %do row_run=1 %to &max_row_num.;
           %do col_run=1 %to &max_col_num.;
                sum(case when (&&row_rest&row_run.&x_y.) and 
                              (&&col_rest&col_run.&x_y.) and 
                              (&&restrictions&x_y..)
            %if &use_idb. = 1 %then %do;
					    %if &use_adj_db. = 1 %then %do; 
							  then (c.&condprop./ eus.pmh_cond_db)
						  %end;
						  %else %do;
		              then (c.&condprop./ eus.pmh_cond)
						  %end;
		                    else 0
					 %end;
					 %else %do;
					    %if &use_adj_db. = 1 %then %do; 
							    then (c.&condprop./ eus.pmh_cond_db)
						  %end;
						  %else %do;
		                    then (c.&condprop./ eus.pmh_cond)
						%end;
		                    else 0
					 %end;

				    end) as r_c_&row_run._&col_run._&x_y.,
           %end;
         %end;
         eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle, ppsa.cycle, 
         ppsa.stratumcd, ppsa.plot
	     from &cond. c,
		      ppsa_temp ppsa,
		      eus_access  eus
           %if "&&add_table&x_y." ne "" %then %do;
		      , &&add_table&x_y.
		   %end;
      where &ppsa_cond_connection. and &ppsa_eus_connection. and
 			eus.evalid in (&evalid.) 
           %if "&&add_connection&x_y." ne "" %then %do;
		    and (&&add_connection&x_y.)
           %end;

	  group by eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle,  ppsa.cycle, 
               ppsa.stratumcd, ppsa.plot
%end;
/* End 5b */
%else %do;
/* 5c */
/*Summarizing mixed estimates*/
     select 
         %do row_run=1 %to &max_row_num.;
           %do col_run=1 %to &max_col_num.;
                sum(case when (&&row_rest&row_run.&x_y.) and 
                              (&&col_rest&col_run.&x_y.) and 
                              (&&restrictions&x_y..)
				   %if &max_variable_of_interest. =1 %then %do;
				     %let var_num = 1;
				   %end;
				   %else %if &&variable_direction&x_y.=2 %then %do;
                     %let var_num =&&row_var&row_run.&x_y.;
				   %end;
				   %else %do;
                     %let var_num =&&col_var&col_run.&x_y.;
				   %end;

					%if "&&variable&var_num&x_y." eq "AREA" %then %do;
					    %if &use_adj_db. = 1 %then %do; 
		                    then (c.&condprop./ eus.pmh_cond_db)
						%end;
						%else %do;
		                    then (c.&condprop./ eus.pmh_cond)
						%end;
					%end;
					%else %do;
                    then ((&&variable&var_num.&x_y.) / &&adj_factor&var_num.)
					%end;
                    else 0
				    end) as r_c_&row_run._&col_run._&x_y.,
           %end;
         %end;
         eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle, ppsa.cycle, 
         ppsa.stratumcd, ppsa.plot
	     from &cond. c,
		      ppsa_temp ppsa,
		      eus_access  eus
           %if "&&add_table&x_y." ne "" %then %do;
		      , &&add_table&x_y.
		   %end;
      where &ppsa_cond_connection. and &ppsa_eus_connection. and
 			eus.evalid in (&evalid.) 
           %if "&&add_connection&x_y." ne "" %then %do;
		    and (&&add_connection&x_y.)
           %end;

	  group by eus.evalid, eus.estunit, ppsa.statecd, ppsa.countycd, ppsa.subcycle,  ppsa.cycle, 
               ppsa.stratumcd, ppsa.plot
%end;
/* End 5c */
	  ) as &x_y._var
	    %if &r. = 1 and &ratio_y_n. eq 1 %then %do; full join 
		                    %end;
    %end;
	    %if &ratio_y_n. eq 1 %then %do;
		    on x_var.evalid    = y_var.evalid and
			   x_var.estunit   = y_var.estunit and
		       x_var.statecd   = y_var.statecd and
		       x_var.stratumcd = y_var.stratumcd and
		       x_var.plot      = y_var.plot and
		       x_var.subcycle  = y_var.subcycle and
		       x_var.countycd  = y_var.countycd
		%end;
     )   as c right join   	     
		 ppsa_temp as ppsa on c.evalid = ppsa.evalid and 
		                   c.estunit   = ppsa.estunit and
                           c.statecd   = ppsa.statecd and 
                           c.stratumcd = ppsa.stratumcd and
                           c.plot      = ppsa.plot and
						   c.subcycle  = ppsa.subcycle and
						   c.cycle     = ppsa.cycle and
						   c.countycd  = ppsa.countycd

	    where ppsa.evalid in (&evalid.)
/* End 4b */
	) as p
	group by p.evalid, p.estunit, p.statecd, p.stratumcd

/* End 4a */
   ) as p,
   eus_access as eus
   where p.evalid    = eus.evalid and
         p.estunit   = eus.estunit and
         p.stratumcd = eus.stratumcd
   group by eus.evalid, eus.estunit,/* p.statecd,*/ eus.stratumcd, eus.p2pointcnt_man
/* End 3 */
   ) as s,

   (
/* 6 */
   select evalid, estunit, 
/*         sum(eus.arealand_eu) as total_area,*/
         sum(eus.stratum_area) as total_area,
		 sum(eus.p2pointcnt_man) as num_plots
		 from eus_access as eus
		 where evalid in (&evalid.)
		 group by evalid, estunit
/* End 6 */
   ) as tot,
   eus_access as eus
   where s.evalid    = eus.evalid and
         s.estunit   = eus.estunit and
         s.stratumcd = eus.stratumcd and
		 s.evalid    = tot.evalid and
		 s.estunit   = tot.estunit
   group by s.evalid, s.estunit
/* End 2 */
   ) as t
      group by t.evalid
/* End 1 */
   ) as t,
     group_evalid g
	 where t.evalid = g.evalid
	   group by g.evalid_group
/* End 1a */
;
quit;

%mend;



/*
%let ratio_y_n=2;
%let count_plots_non_zero=1;
%estimation;

proc print data = estimation;run;
proc print data = estimation_d;run;
*/

